@@ -11,7 +11,6 @@ import (
 	"github.com/alecthomas/kong"
 )
 
-// nolint: govet
 type threeArg struct {
 	RequiredThree bool   `required`
 	Three         string `arg`
@@ -54,7 +53,6 @@ Flags:
 }
 
 func TestHelp(t *testing.T) {
-	// nolint: govet
 	var cli struct {
 		String   string         `help:"A string flag."`
 		Bool     bool           `help:"A bool flag with very long help that wraps a lot and is verbose and is really verbose."`
@@ -163,7 +161,6 @@ Flags:
 }
 
 func TestFlagsLast(t *testing.T) {
-	// nolint: govet
 	var cli struct {
 		String   string         `help:"A string flag."`
 		Bool     bool           `help:"A bool flag with very long help that wraps a lot and is verbose and is really verbose."`
@@ -272,7 +269,6 @@ Flags:
 }
 
 func TestHelpTree(t *testing.T) {
-	// nolint: govet
 	var cli struct {
 		One struct {
 			Thing struct {
@@ -346,7 +342,7 @@ Run "test-app <command> --help" for more information on a command.
 			require.NoError(t, err)
 		})
 		require.True(t, exited)
-		expected := `Usage: test-app one <command>
+		expected := `Usage: test-app one (un,uno) <command>
 
 subcommand one
 
@@ -367,7 +363,6 @@ Commands:
 }
 
 func TestHelpCompactNoExpand(t *testing.T) {
-	// nolint: govet
 	var cli struct {
 		One struct {
 			Thing struct {
@@ -419,7 +414,7 @@ Commands:
   two    Another subcommand.
 
 Group A
-  one    subcommand one
+  one (un,uno)    subcommand one
 
 Run "test-app <command> --help" for more information on a command.
 `
@@ -437,7 +432,7 @@ Run "test-app <command> --help" for more information on a command.
 			require.NoError(t, err)
 		})
 		require.True(t, exited)
-		expected := `Usage: test-app one <command>
+		expected := `Usage: test-app one (un,uno) <command>
 
 subcommand one
 
@@ -445,8 +440,8 @@ Flags:
   -h, --help    Show context-sensitive help.
 
 Group A
-  one thing      subcommand thing
-  one <other>    subcommand other
+  one (un,uno) thing      subcommand thing
+  one (un,uno) <other>    subcommand other
 `
 		if expected != w.String() {
 			t.Errorf("help command returned:\n%v\n\nwant:\n%v", w.String(), expected)
@@ -466,7 +461,23 @@ func TestEnvarAutoHelp(t *testing.T) {
 	require.Contains(t, w.String(), "A flag ($FLAG).")
 }
 
-func TestCustomHelpFormatter(t *testing.T) {
+func TestEnvarAutoHelpWithEnvPrefix(t *testing.T) {
+	type Anonymous struct {
+		Flag  string `env:"FLAG" help:"A flag."`
+		Other string `help:"A different flag."`
+	}
+	var cli struct {
+		Anonymous `envprefix:"ANON_"`
+	}
+	w := &strings.Builder{}
+	p := mustNew(t, &cli, kong.Writers(w, w), kong.Exit(func(int) {}))
+	_, err := p.Parse([]string{"--help"})
+	require.NoError(t, err)
+	require.Contains(t, w.String(), "A flag ($ANON_FLAG).")
+	require.Contains(t, w.String(), "A different flag.")
+}
+
+func TestCustomValueFormatter(t *testing.T) {
 	var cli struct {
 		Flag string `env:"FLAG" help:"A flag."`
 	}
@@ -474,7 +485,7 @@ func TestCustomHelpFormatter(t *testing.T) {
 	p := mustNew(t, &cli,
 		kong.Writers(w, w),
 		kong.Exit(func(int) {}),
-		kong.HelpFormatter(func(value *kong.Value) string {
+		kong.ValueFormatter(func(value *kong.Value) string {
 			return value.Help
 		}),
 	)
@@ -484,7 +495,6 @@ func TestCustomHelpFormatter(t *testing.T) {
 }
 
 func TestHelpGrouping(t *testing.T) {
-	// nolint: govet
 	var cli struct {
 		GroupedAString string `help:"A string flag grouped in A." group:"Group A"`
 		FreeString     string `help:"A non grouped string flag."`
@@ -714,3 +724,38 @@ test: error: missing flags: --flag=STRING
 `
 	require.Equal(t, expected, w.String())
 }
+
+func TestCustomWrap(t *testing.T) {
+	var cli struct {
+		Flag string `help:"A string flag with very long help that wraps a lot and is verbose and is really verbose."`
+	}
+
+	w := bytes.NewBuffer(nil)
+	app := mustNew(t, &cli,
+		kong.Name("test-app"),
+		kong.Description("A test app."),
+		kong.HelpOptions{
+			WrapUpperBound: 50,
+		},
+		kong.Writers(w, w),
+		kong.Exit(func(int) {}),
+	)
+
+	_, err := app.Parse([]string{"--help"})
+	require.NoError(t, err)
+	expected := `Usage: test-app
+
+A test app.
+
+Flags:
+  -h, --help           Show context-sensitive
+                       help.
+      --flag=STRING    A string flag with very
+                       long help that wraps a lot
+                       and is verbose and is
+                       really verbose.
+`
+	t.Log(w.String())
+	t.Log(expected)
+	require.Equal(t, expected, w.String())
+}
