@@ -127,6 +127,18 @@ func TestDurationMapper(t *testing.T) {
 	require.Equal(t, time.Second*5, cli.Flag)
 }
 
+func TestDurationMapperJSONResolver(t *testing.T) {
+	var cli struct {
+		Flag time.Duration
+	}
+	resolver, err := kong.JSON(strings.NewReader(`{"flag": 5000000000}`))
+	require.NoError(t, err)
+	k := mustNew(t, &cli, kong.Resolvers(resolver))
+	_, err = k.Parse(nil)
+	require.NoError(t, err)
+	require.Equal(t, time.Second*5, cli.Flag)
+}
+
 func TestSplitEscaped(t *testing.T) {
 	require.Equal(t, []string{"a", "b"}, kong.SplitEscaped("a,b", ','))
 	require.Equal(t, []string{"a,b", "c"}, kong.SplitEscaped(`a\,b,c`, ','))
@@ -452,3 +464,34 @@ func (t testMapperWithPlaceHolder) Decode(ctx *kong.DecodeContext, target reflec
 func (t testMapperWithPlaceHolder) PlaceHolder(flag *kong.Flag) string {
 	return "/a/b/c"
 }
+
+func TestMapperVarsContributor(t *testing.T) {
+	var cli struct {
+		Flag string `help:"Some help with ${avar}"`
+	}
+	b := bytes.NewBuffer(nil)
+	k := mustNew(
+		t,
+		&cli,
+		kong.Writers(b, b),
+		kong.ValueMapper(&cli.Flag, testMapperVarsContributor{}),
+		kong.Exit(func(int) { panic("exit") }),
+	)
+	// Ensure that --help
+	require.Panics(t, func() {
+		_, err := k.Parse([]string{"--help"})
+		require.NoError(t, err)
+	})
+	require.Regexp(t, "--flag=STRING\\s+Some help with a var", b.String())
+}
+
+type testMapperVarsContributor struct{}
+
+func (t testMapperVarsContributor) Vars(value *kong.Value) kong.Vars {
+	return kong.Vars{"avar": "a var"}
+}
+
+func (t testMapperVarsContributor) Decode(ctx *kong.DecodeContext, target reflect.Value) error {
+	target.SetString("hi")
+	return nil
+}
